from setuptools import setup

setup(name='bmywp',
      version='0.1',
      description='BymBit Rest API wrapper',
      url='https://github.com/abdesslem/bmywp',
      author='Abdesslem Amri',
      author_email='amriabdesslem@gmail.com',
      license='GPLv3.0',
      packages=['bmywp'],
      zip_safe=False)
